__import__("pkg_resources").declare_namespace(__name__)

import sys
import os
from logging import getLogger
from infi.pyutils.decorators import wraps

BYPASS_KEY = "ROOT_BYPASS"
logger = getLogger()

class RootPermissions(object):
    def _nt(self):
        from .windows import is_admin
        return is_admin()

    def _posix(self):
        return os.getuid() == 0

    def _bypass(self):
        return os.environ.get(BYPASS_KEY, False)

    def is_root(self):
        if self._bypass():
            return True

        if os.name != "nt":
            return self._posix()
        return self._nt()

def exit_if_not_root(func):
    @wraps(func)
    def callee(*args, **kwargs):
        if not RootPermissions().is_root():
            username = "an Administrator" if os.name == "nt" else "root"
            msg = "You must be {} to run this tool".format(username)
            sys.stderr.write("{}\n".format(msg))
            logger.error(msg)
            sys.stderr.flush()
            sys.exit(5)
        return func(*args, **kwargs)
    return callee

@exit_if_not_root
def ensure_root():
    pass



__version__ = "0.1.3"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(detached from v0.1.3)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'a403688e2c221aec2cfd56513763ac037adcf718'
__git_head_subject__ = 'Finished release v0.1.3.'
__git_head_message__ = '* release/v0.1.3:\n  buildout.cfg: adding setuptools to requirements\n  buildout.cfg: remove distribute from requirements\n  update dependencies'
__git_dirty_diff__ = ''